
* GDP
import delimited "Input/GDP.csv", varnames(1) clear 

	drop seriescode
	drop if country == ""
	reshape long yr, i(country reporteriso3 seriesname) j(year)

	replace seriesname = "GDP" if seriesname=="GDP (constant 2010 US$)"
	replace seriesname = "GDPpc" if seriesname=="GDP per capita (constant 2010 US$)"
	drop if seriesname==""
	destring yr, force replace

	reshape wide yr, i(country reporteriso3 year) j(seriesname) string
	rename yr* *
	save "Output/Intermediate/GDP", replace
	 
 
* Export to EU 
import delimited "Input/Export_toEU_HS6.csv", varnames(1) clear 
	tostring productcode, ge(HS6)
	replace HS6 = "0" + HS6 if productcode<100000


	ge first = substr(HS6, 1, 4)
	ge second = substr(HS6, 5, 6)
	replace HS6 = first + "." + second 
	drop first second 

	drop productcode partnername tradeflowname tradeflowcode nomencl

	rename year Year
	rename reporteriso3 ReporterISO3 
	rename tradevaluein1000usd exptoEU27


	save "output/trade_to_EU" , replace

 
* Export to world  
import delimited "Input/Export_HS6.csv", varnames(1) clear case(preserve) stringcols(2)

rename ProductCode HS6
	
ge HS2 = substr(HS6, 1, 2)
encode HS2, ge(HS2n)

ge first = substr(HS6, 1, 4)
ge second = substr(HS6, 6, 2)
replace HS6 = first + "." + second 
drop first second 

keep ReporterISO3 Year HS6 TradeValuein1000USD ReporterIncomeGroup ReporterRegion


merge 1:1  ReporterISO3 Year HS6 using "output/trade_to_EU"
	drop if _m==2
	drop _m


merge m:1 HS6 using "input/DDT_DLTL_HS6.dta"
	drop _m
	
ge HS2 = substr(HS6, 1, 2)
encode HS2, ge(HS2n)

ge textile = HS2n>=50 & HS2n<=63 	
drop if HS2 == "41" | HS2 == "42" | HS2 == "43"  // Leather as partially treated by DLTL (non-textile subsidy)
drop if HS2n>=64 & HS2n <= 67   // Footwear as partially treated by DLTL non-textile subsidy
drop if HS2n<16 // Agric
drop if HS2n>=25 & HS2n <= 25   // Mineral
drop if DLTLttreat==1 // drop products affected by non-textile subsidies

ge DDT_NCH6 = "Garments" 			if H6_Garments==1
replace DDT_NCH6 = "Madeups" 		if H6_Madeups==1 
replace DDT_NCH6 = "Processed" 		if H6_Processed==1
replace DDT_NCH6 = "FabricYarn" 	if H6_FabricYarn==1
replace DDT_NCH6 = "Nonelig" 		if H6_Nonelig==1 
 
replace DDT_NCH6 = "Notextile" if notreat==1  // we exclude HS2 lines where there is at least one HS8 code treated with non-textile subsidies
replace DDT_NCH6 = "Notextile" if textile==0

rename  TradeValuein1000USD Exports
rename  Year year
rename  ReporterISO3 reporteriso3

save "Output/Intermediate/Data_beforecollapse", replace

drop if textile==0
collapse (sum) Exports exptoEU27, by(year  reporteriso3 ReporterIncomeGroup ReporterRegion)

encode reporteriso3, ge(countryid)

merge m:1 reporteriso3 year using  "Output/Intermediate/GDP"
drop if _m==2
drop _m

drop if reporteriso3=="ABW"
drop if reporteriso3 == "OAS"
drop if GDP==. & year!=2020


ge Exports_noEU = Exports - exptoEU27
drop if year==2020

collapse (sum) Exports  Exports_noEU (mean) GDP GDPpc , by( year reporteriso3 countryid ReporterIncomeGroup ReporterRegion)		
save "Output/Overall_NC", replace


use  "Output/Intermediate/Data_beforecollapse", clear
collapse (sum) Exports exptoEU27, by(DDT_NCH6 year reporteriso3 ReporterIncomeGroup ReporterRegion)

merge m:1 reporteriso3 year using  "Output/Intermediate/GDP"
drop if _m==2
drop _m


drop if reporteriso3=="ABW"
drop if reporteriso3 == "OAS"
drop if GDP==. & year!=2020

ge Exports_noEU = Exports - exptoEU27
drop if year==2020
save "Output/Data_by_category", replace


*============== by chapter
use  "Output/Intermediate/Data_beforecollapse", clear

ge DDTCh = ""
replace DDTCh = "Notextile" if textile==0
replace DDTCh = "Nonelig"   if HS2n==50 | HS2n==52 | HS2n==56
replace DDTCh = "FabricYarn" if HS2n==51 | HS2n==58 
replace DDTCh = "Garments"  if HS2n==61 | HS2n==62
replace DDTCh = "Madeups"   if HS2n==57 | HS2n==63
replace DDTCh = "Processed" if HS2n==59 | HS2n==60 | HS2n==55 | HS2n==54 | HS2n==53 


collapse (sum) Exports exptoEU27, by(HS2 year DDTCh reporteriso3 ReporterIncomeGroup  ReporterRegion)

encode reporteriso3, ge(countryid)

merge m:1 reporteriso3 year using  "Output/Intermediate/GDP"
drop if _m==2
drop _m


drop if reporteriso3=="ABW"
drop if reporteriso3 == "OAS"
drop if GDP==. & year!=2020

ge Exports_noEU = Exports - exptoEU27
drop if year==2020

save "Output/Data_for_synt_chapters", replace


*============== by chapter/treatment
use  "Output/Intermediate/Data_beforecollapse", clear

ge DDTCh = ""
replace DDTCh = "Notextile" if textile==0
replace DDTCh = "Nonelig"   if HS2n==51 | HS2n==58 | HS2n==50 | HS2n==52 | HS2n==56
replace DDTCh = "Garments"  if HS2n==61 | HS2n==62
replace DDTCh = "Madeups"   if HS2n==57 | HS2n==63
replace DDTCh = "Processed" if HS2n==59 | HS2n==60 | HS2n==55 | HS2n==54 | HS2n==53 

collapse (sum) Exports exptoEU27, by(DDTCh year reporteriso3 ReporterIncomeGroup  ReporterRegion)

encode reporteriso3, ge(countryid)

merge m:1 reporteriso3 year using  "Output/Intermediate//GDP"
drop if _m==2
drop _m


drop if reporteriso3=="ABW"
drop if reporteriso3 == "OAS"
drop if GDP==. & year!=2020


ge Exports_noEU = Exports - exptoEU27
drop if year==2020

save "Output/Data_for_synt_DDTCh", replace




