

set more off


import delimited "Input/PAK_export_to_top20_all_08_10.csv", varnames(1) clear 
tab year

	rename tradevaluein1000usd ExpvUSD
	rename quantity Expq

	drop rep*
	rename partneriso3 country
	drop tradeflow*

	tempfile top201
	save `top201'

import delimited "Input/PAK_export_to_top20_all_11_15.csv", varnames(1) clear 
tab year

	rename tradevaluein1000usd ExpvUSD
	rename quantity Expq

	drop rep*
	rename partneriso3 country
	drop tradeflow*

	tempfile top202
	save `top202'

import delimited "Input/PAK_export_to_top20_all_16_19.csv", varnames(1) clear 
tab year

	rename tradevaluein1000usd ExpvUSD
	rename quantity Expq

	drop rep*
	rename partneriso3 country
	drop tradeflow*

	tempfile top203
	save `top203'

use `top201'
append using `top202'
append using `top203'

tab year

save "Output/PAKexport_top20", replace 

**** Import
import delimited "Input/Top20imports_from_PAK_all_09_14.csv", varnames(1) clear 
tab year

	rename tradevaluein1000usd ImpvUSD
	rename quantity Impq

	drop part*
	rename reporteriso country
	drop tradeflow*

	tempfile imp201
	save `imp201'

**** Import
import delimited "Input/Top20imports_from_PAK_all_15_19.csv", varnames(1) clear 
tab year

	rename tradevaluein1000usd ImpvUSD
	rename quantity Impq

	drop part*
	rename reporteriso country
	drop tradeflow*

	tempfile imp202
	save `imp202'

use `imp201'
append using `imp202'

tab year

save "Output/PAKimport_top20", replace

*===============================================================================
*  Constructing dataset
*===============================================================================

use "Output/PAKexport_top20", clear

merge 1:1 productcode country year  using "Output/PAKimport_top20"
drop _m

ge noimp = ExpvUSD!=. & ImpvUSD==.
ge noexp = ExpvUSD==. & ImpvUSD!=.

bysort country year: ge totitem = _N
bysort country year: egen CCnoimp = total(noimp)
bysort country year: egen CCnoexp = total(noexp)
ge s_noimp = CCnoimp/totitem
ge s_noexp = CCnoexp/totitem

tabstat s_noimp s_noexp, by(country) stats(mean max )

tostring(productcode), gen(HS6)
replace HS6 = "0" + HS6 if productcode<100000
order HS6

ge first = substr(HS6, 1, 4)
ge second = substr(HS6, 5, 6)
replace HS6 = first + "." + second 
drop first second

order HS6 

ge HS2 = substr(HS6, 1, 2)
destring HS2, ge(HS2n)

ge DDTCh = ""
replace DDTCh = "Notextile" if HS2n<50 | HS2n>63
replace DDTCh = "Nonelig"   if HS2n==51 | HS2n==58 | HS2n==50 | HS2n==52 | HS2n==56
replace DDTCh = "Garments"  if HS2n==61 | HS2n==62
replace DDTCh = "Madeups"   if HS2n==57 | HS2n==63
replace DDTCh = "Processed" if HS2n==59 | HS2n==60 | HS2n==55 | HS2n==54 | HS2n==53 


merge m:1 HS6 using "Input/DDT_DLTL_HS6.dta"
drop if _m==2
drop _m

ge DDT_NCH6 = "Garments" 			if H6_Garments==1
replace DDT_NCH6 = "Madeups" 		if H6_Madeups==1 
*| H6_Processed==1
replace DDT_NCH6 = "Processed" 		if H6_Processed==1
replace DDT_NCH6 = "FabricYarn" 	if H6_FabricYarn==1
replace DDT_NCH6 = "Nonelig" 	if H6_Nonelig==1

replace DDT_NCH6 = "Notextile" if HS2n<50 | HS2n>63
tab DDT_NCH6, m
drop if DDT_NCH6==""

sum ImpvUSD Impq ExpvUSD Expq
recode  ImpvUSD Impq ExpvUSD Expq (.=0)

local var "ImpvUSD Impq ExpvUSD Expq"

foreach i of local var{
	ge l_`i' = ln(`i')
	ge lp1_`i' = ln(1 +`i')
} 


ge unitgap = ln(ExpvUSD/Expq) - ln(ImpvUSD/Impq)
ge unitgap_p1 = ln((1+ExpvUSD)/(1+Expq)) - ln((1+ImpvUSD)/(1+Impq))
ge gapvalue = ln(ExpvUSD) - ln(ImpvUSD)
ge gapvalue_p1 = ln(ExpvUSD + 1) - ln(ImpvUSD + 1)
ge gapvalue_p1_adj = ln(ExpvUSD + 1) - ln(ImpvUSD/1.1 + 1)

ge gapvalue_ln = ln(ExpvUSD - ImpvUSD)

ge absgap = abs(ExpvUSD - ImpvUSD)
ge positvegap = (ExpvUSD - ImpvUSD)

** total reported exports by category-year
bysort DDT_NCH6 year: egen totexp = total(ExpvUSD)

** total reported imports by category-year
bysort DDT_NCH6 year: egen totimp = total(ImpvUSD)

** sum of absolute values
** the closer the EWF comes to zero, the less misreporting we detect; as the EWF approaches one, more and more misreporting is detected.
bysort DDT_NCH6 year: egen totabs = total(abs(ExpvUSD - ImpvUSD))
bysort DDT_NCH6 year: egen totpos = total((ExpvUSD - ImpvUSD))

ge EWF = 1 - totabs/(totexp+totimp) 
ge EWF_pos = totpos/(totexp+totimp)
ge expgap = (ExpvUSD - ImpvUSD)/(totexp+totimp)

lab var ExpvUSD "Pakistan export to destination, 000USD"
lab var ImpvUSD "Country import from Pakistan, 000USD"

save "Output/Data_for_misreporting_all_NC", replace

