

use "output/Data_for_analysis_8digit.dta", clear

replace ExportsRs = ExportsRs/1000000
replace  ExportsRs = ExportsRs/118.5138 // conversion
recode ExportsRs (.=0)

egen HS2_n = group(HS2)
egen HS4_n = group(HS4)
egen HS8_n = group(HS8)
egen HS6_n = group(HS6)
egen tagHS8 = tag(HS8)

keep if textile==1
drop if year==2020
keep if year>=2007

ge DDT_n = DDT_NC != "Noneligible" & DDT_NC != "FabricYarn"
bysort HS4: egen meanDDT4 = mean(DDT_n)
bysort HS2: egen meanDDT2 = mean(DDT_n)


ge treated =  1 if DDT_NC == "Garments"
replace treated = 2 if DDT_NC =="Madeups"
replace treated = 3 if DDT_NC =="Processed"
replace treated = 4 if DDT_NC =="FabricYarn"
replace treated = 0 if DDT_NC =="Noneligible"

ge lnexp = ln(ExportsRs)

drop if ExportsRs==.

* FIGURE 1 - Overall trends by eligibility criteria
preserve
	collapse (sum) ExportsRs , by(year treated)	
	keep if year>2007

	reshape wide ExportsRs , i(year) j(treated)
	order year ExportsRs*
	
		ge labgarments = "Garments (High)" if year == 2019
		ge labMadeups = "Made-ups (Medium)" if year == 2017		
		ge labProcessed = "Processed (Low)" if year == 2011	
		ge labFabricYarn = "Fabrics-Yarn (Very low)" if year == 2015			
		ge labnoneleg = "Non-eligible (None)" if year == 2012	

twoway 	(connected ExportsRs0 year , msymbol(circle_hollow)  	lpattern(line) mlabel(labnoneleg) mlabposition(12)) ///
		(connected ExportsRs1 year , msymbol(circle) 		 	lpattern(dash) mlabel(labgarments) mlabposition(11)) /// 		
		(connected ExportsRs2 year , msymbol(circle) 		 	lpattern(line) mlabel(labMadeups) mlabposition(12) mlabgap(2) ) ///		
		(connected ExportsRs3 year , msymbol(circle_hollow)		lpattern(line) mlabel(labProcessed) mlabposition(1)) ///		
		(connected ExportsRs4 year , msymbol(circle_hollow) 	lpattern(line) mlabel(labFabricYarn) mlabposition(7)) ///			
		, title("") legend (off) ytitle("Total exports") xtitle("Year") name(manual, replace) xline(2014.5)	///
		xlabel(2008(1)2020, angle(vertical))	
		graph export "output/figures/overview_NC.png",  replace
restore 


*===============================================================================
* Event study
*===============================================================================


keep if textile==1
ge time = year
sum time
global numyearmax = r(max)
global numyearmin = r(min)	

replace ExportsRs = ExportsRs*118.5138 // re-conversion
replace ExportsRs = ExportsRs/gdpdef*100 // Constant prices

sum time if year==2014 // Baseline
global treatdummy = r(min)	

drop *treated
ge d_treated_ev = 0 if DDT_NC=="Noneligible" 

local lDDT_NC "Garments Madeups Processed FabricYarn"

foreach s of local lDDT_NC{

	preserve	

		global type = "`s'"
		display "$type"
		replace d_treated_ev = 1 if DDT_NC =="$type"

		forvalues i = $numyearmin(1)$numyearmax{
			ge d_time`i'  = time==`i'
			ge id_treated_`i' = d_treated_ev * d_time`i'
				}
			** dropping the treatment year		
			drop id_treated_${treatdummy} d_time${treatdummy} 

			
		xtset HS8_n time
		drop if year<2008	
		table year d_treated_ev, stat(mean ExportsRs)
		xtreg ExportsRs d_time* id_treated_*   , fe cluster(HS2_n) baselevels			
		
		regsave  using "output/es_coeff_`s'" , replace tstat pval ci level(95) 	


				if "$type" == "Noneligible" {
					global title "Non-eligible"
				}
				if "$type" == "Madeups" {
					global title "Madeups"
				}		
				if "$type" == "Processed" {
					global title "Processed"
				}
				if "$type" == "Garments" {
					global title "Garments"	
				}
				if "$type" == "FabricYarn" {
					global title "FabricYarn"
				}		


		tabstat tagHS8 if e(sample) & d_treated_ev==0, stats(sum)
		tabstat tagHS8 if e(sample) & d_treated_ev==1, stats(sum)


		use "output/es_coeff_`s'", clear

			ge parm_2 = strpos(var,  "id_treated")
			keep if parm_2==1 | var == "_cons"

			ge year=substr(var,12,4)
			destring year, force replace
			replace year = 2014 if year==.
			replace coef = 0 if parm_2==0	
			replace ci_lower = 0 if parm_2==0	
			replace ci_upper = 0 if parm_2==0	
			sort year
				
			twoway (scatter coef year, lcolor(black) msymbol(circle_hollow) ) ///
				(rbar ci_lower ci_upper year, barwidth(.02) color(black) /// 
				lcolor(black)  lpattern(line)) ///	
				(scatter coef year if inrange(year,2008,2014), mcolor(blue) ///
				lcolor(blue) msymbol(circle_hollow) ) ///
				(rbar ci_lower ci_upper year if inrange(year,2008,2014), ///
				barwidth(.02) mcolor(blue) lcolor(blue)   lpattern(line)) ///				   
				, xline( 2014.5  )  ytitle("Coefficient of ($type) X (year)") ///
				xtitle("") yline(0,  lcolor(black) lpattern(dash)) ///
				xlabel(2008(1)2019, angle(vertical)) ylabel(#10) ///
				name(a$title, replace) 	legend(off)	scheme(s1mono) title("") 
				graph export "output/figures/es_${type}_NC.png",  replace
		
	restore
}	


* Garments vs others

preserve	

	replace d_treated_ev = 1 if DDT_NC =="Garments"
	replace d_treated_ev = 0 if textile==1 & DDT_NC !="Garments"

	forvalues i = $numyearmin(1)$numyearmax{
		ge d_time`i'  = time==`i'
		ge id_treated_`i' = d_treated_ev * d_time`i'
			}
		** dropping the treatment year		
		drop id_treated_${treatdummy} d_time${treatdummy} 

			
	xtset HS8_n time
	drop if year<2008	
	
	table year d_treated_ev, stat(mean ExportsRs)
	xtreg ExportsRs d_time* id_treated_*   , fe cluster(HS2_n) baselevels

	regsave  using "output/es_coeff_others" , replace tstat pval ci level(95) 	

	use "output/es_coeff_others", clear

		ge parm_2 = strpos(var,  "id_treated")
		keep if parm_2==1 | var == "_cons"

		ge year=substr(var,12,4)
		destring year, force replace
		replace year = 2014 if year==.
		replace coef = 0 if parm_2==0	
		replace ci_lower = 0 if parm_2==0	
		replace ci_upper = 0 if parm_2==0	
		sort year
				
		twoway (scatter coef year, lcolor(black) msymbol(circle_hollow) ) ///
				(rbar ci_lower ci_upper year, barwidth(.02) color(black) /// 
				lcolor(black)  lpattern(line)) ///	
				(scatter coef year if inrange(year,2008,2014), mcolor(blue) ///
				lcolor(blue) msymbol(circle_hollow) ) ///
				(rbar ci_lower ci_upper year if inrange(year,2008,2014), ///
				barwidth(.02) mcolor(blue) lcolor(blue)   lpattern(line)) ///				   
				, xline( 2014.5  )  ytitle("Coefficient of (Garments) X (year)") ///
				xtitle("") yline(0,  lcolor(black) lpattern(dash)) ///
				xlabel(2008(1)2019, angle(vertical)) ylabel(#10) ///
				name(aothers, replace) 	legend(off)	scheme(s1mono) title("") 
				graph export "output/figures/es_Garments_others_NC.png",  replace
		
	restore

	
ge post = year>2014

ge treat_Garments = 1 if DDT_NC=="Garments"
replace treat_Garments= 0 if textile==1 & DDT_NC!="Garments" & DDT_NC!="Madeups" 

ge treat_Madeups = 1 if DDT_NC=="Madeups"
replace treat_Madeups= 0 if textile==1 & DDT_NC!="Garments" & DDT_NC!="Madeups" 

ge treat_Processed = 1 if DDT_NC=="Processed"
replace treat_Processed= 0 if textile==1 & DDT_NC=="Garments" | DDT_NC=="Madeups" 

ge treat_FabricYarn= 1 if DDT_NC=="FabricYarn"
replace treat_FabricYarn= 0 if textile==1 & DDT_NC=="Garments" | DDT_NC=="Madeups" 

ge treat_Noneligible= 1 if DDT_NC=="Noneligible"
replace treat_Noneligible= 0 if textile==1 & DDT_NC=="Garments" | DDT_NC=="Madeups" 

local category "Garments Madeups Processed FabricYarn Noneligible"

foreach y of local category{
	areg ExportsRs post##treat_`y' , absorb(HS8_n)
	estimates store did_`y'
}

esttab did_*  , 	nocons cells(b(fmt(3) star) se(fmt(3) par)  )  noomit  /// 
		starlevels(* 0.1 ** 0.05 *** 0.01) stats(N df_a , fmt(0 0 )) drop(0.* _cons)	nogaps noomit 
					

