

use  "Output/Data_for_synt_DDTCh", clear

drop if DDTCh=="Notextile"

replace Exports = Exports/1000000 // billion USD
replace exptoEU = exptoEU/1000000 // billion USD
drop if year==2008 | year ==2007 
drop if year==2020


drop if reporteriso3=="HKG"
bysort reporteriso3 DDTCh: ge count = _N
tab count
keep if count>=11 // only countries with data for all years
drop count
unique reporteriso3

bysort reporteriso3 DDTCh: egen tottextile = total(Exports) if DDTCh!="Notextile"
bysort DDTCh: egen tottot = total(Exports) if DDTCh!="Notextile"
ge sharetemp = tottextile/tottot
bysort reporteriso3: egen share = max(share)

tabstat Exports if reporteriso3=="PAK" , by(DDTCh) stat(sum)

global gall "Exports(2009) Exports(2010) Exports(2011) Exports(2012) Exports(2013) Exports(2014)"


levelsof DDTCh, local(lDDTCh)

foreach i of local lDDTCh{
	preserve
	display "`i'"
	global type = "`i'"
	keep if DDTCh=="`i'"
	replace share = -share
	bysort year (share): gen order = _n
	keep if order<=40
	unique reporteriso3
	xtset countryid year
	sum countryid if reporteris =="PAK"
	global PAK = r(mean)
	
	#delimit; 
	synth   Exports  
			${gall}   ,       
			trunit($PAK) trperiod(2015) unitnames(reporteriso3) 
			mspeperiod(2009(1)2015) resultsperiod(2009(1)2019)
			keep(output/f`i'_NC)  replace;
			mat list e(V_matrix);
	#delimit cr 
	restore 
	
	preserve	
	use output/f`i'_NC, clear
	
	if "`i'" == "Processed" {
		global position = 2
	}
	
	if "`i'" != "Processed" {
		global position = 5
	}

	twoway (line _Y_treated  _time) (line _Y_synthetic _time , lpattern(dash)), ///
	title("") name(f`i', replace)  xline(2014.5) xlabel(2009(1)2019) ///
	ytitle("Exports (bl USD)") ylabel(0(1)4) xtitle("") legend(order(1 "Pakistan" 2 "Synthetic control") ring(0) position($position)) 	
	graph export "output/figures/synt_`i'_NC.png",  replace
	
	restore
}


**************************************************************
** weigths
**************************************************************

foreach i of local lDDTCh{
	use output/f`i'_NC, clear
	keep if _W_Weight!=0
	keep _Co_Number _W_Weight
	ge type = "`i'"
	tempfile w_`i'
	save `w_`i''
}


use `w_Garments'
foreach i of local lDDTCh{
	append using `w_`i''
	duplicates drop
	save output/weights, replace
}

rename _W_ weight
rename _Co country
reshape wide weight, i(country) j(type) string

export excel using "Output/Tables/TableA3.xlsx", firstrow(variables) replace

**************************************************************
** Total exports
**************************************************************

use  "output/Overall_NC", clear	


	replace Exports = Exports/1000000
	
	drop if ReporterIncomeGroup=="High income"

	bysort reporteriso3 : ge numcountries = _N

	sum numcountries
	global max = r(max)
	keep if numcountries==12		
	sum countryid if reporteris =="PAK"
	global PAK = r(mean)	
	
	xtset countryid year

	#delimit; 
	synth   Exports  
			Exports(2008) Exports(2009) Exports(2010)  Exports(2011) Exports(2012)  Exports(2013) 
			Exports(2014)  ,       
			trunit($PAK) trperiod(2015) unitnames(reporteriso3) 
			mspeperiod(2009(1)2015) resultsperiod(2009(1)2019)
			keep(output/fall_NC)   replace;
			mat list e(V_matrix);
	#delimit cr 
	
preserve	
	use output/fall_NC, clear

	twoway (line _Y_treated  _time) (line _Y_synthetic _time , lpattern(dash)), title("") name(fall5, replace)  xline(2014.5)  xtitle(year) ytitle("Exports (bl USD)")  xlabel(2009(1)2019) legend(order(1 "Pakistan" 2 "Synthetic control") ring(0) position(5)) ylabel(0(2)14)
	graph export "output/figures/synt_all_NC.png",  replace
restore
		

