
use "Input/Exporter_transaction_2008_2021.dta", replace

	egen exporterid = group(NTN year)
	replace export_value = export_value/1000000  // million USD	
	bysort exporterid: egen size = total(export_value)

		
		ge treated =  1 if DDT_NCH6 == "Garments"
		replace treated = 1 if DDT_NCH6 =="Madeups"
		replace treated = 0 if DDT_NCH6 =="Processed"
		replace treated = 0 if DDT_NCH6 =="FabricYarn"
		replace treated = 0 if DDT_NCH6 =="Nonelig"
		replace treated = . if DDT_NCH6 ==""
		
		ge textile = HS2n>=50 & HS2n<=63 
		bysort exporterid: egen notextile = max(textile)

		
		keep if year>2014
		drop if year>=2020
		
		unique NTN // 41360
		keep if textile==1
		unique NTN // 19734
		
		ge H6_highrate = DDT_NCH6=="Garments" | DDT_NCH6=="Madeups"
		ge H6_lowrate = DDT_NCH6=="FabricYarn" | DDT_NCH6=="Nonelig" | DDT_NCH6=="Processed"


		bysort NTN year: egen mean_high = mean(H6_highrate)
		unique NTN if mean_high<0.8
		unique NTN if mean_high==1	
		drop if mean_high==1 // only exporters that export both low and high rate products
	
		tab year // 3 years per period
		
		table treated year, stat(sum export_value)
		
		sum size, d
		ge quantile = .
		levelsof year, local(lyear)
			
		foreach i of local lyear{
		xtile quantile_`i' = size if year==`i', nq(100)
		replace quantile = quantile_`i' if year==`i'
		}
		
		drop quantile_*
		ge q_size = 1 if quantile>=99	// 99 works
		replace q_size = 2 if quantile<99
		
		ge decile = 1 if quantile>95	
			replace decile = 2 if quantile<=95 & quantile>75	
			replace decile = 3 if quantile<=75 & quantile>50	
			replace decile = 4 if quantile<=50	
			
		tabstat export_value, by(decile) stat(sum)	

		ge first = substr(HS6, 1, 4)
		ge second = substr(HS6, 5, 6)
		replace HS6 = first + "." + second 
		drop first second 
		

			collapse (sum) export_value, by(year treated decile HS6)
				
			ge HS4 = substr(HS6, 1, 4)	
			ge HS2 = substr(HS6, 1, 2)		
			
			forvalues i = 1(1)4{
				areg export_value  year##treated  if decile==`i' , cluster(HS2) absorb(HS2)
				estimates store dec`i'			
			}
			
			coefplot dec1, xline(0) bylabel(Top 5%)   ///
					|| dec2 ,   bylabel(Top 5-25%) ///
					|| dec3 ,   bylabel(Top 25-50%) ///
					|| dec4 ,   bylabel(Bottom 50%) ///				
					||, drop(_cons  1.treated) byopts(xrescale) ///
					   ylabel(1 "{bf:Lower rates}"  2 "2016" 3 "2017"  4 "2018"  5 "2019"   ///
						   6 "{bf:Medium-High rates}" 7 "2016" 8 "2017"  9 "2018"  10 "2019"  ) ///
						   ytitle(Changes in export with respect to 2015) ///
						   headings(2016.year = "ddd" 2016.year#1.treated = "ddd", nogap )					   
						   
			graph export "output/figures/capacity_results.png", replace		
					

		
