set more off

use "output/Data_for_misreporting_all_NC", clear

** top 10
keep if country=="USA" | country=="CHN" | country=="GBR" | country=="DEU" | country=="ESP" ///
	  | country=="BEL" | country=="ITA" | country=="NDL" | country=="ARE" | country=="FRA" 


rename ExpvUSD value_Exp
rename ImpvUSD value_Imp

ge post = year>2015

** Analysis by treatment category for textile products
collapse  value* , by( HS6  year DDT_NCH6 ) 
fillin   HS6 year  

sum year
global total = r(N)
cap drop check
encode DDT_NCH6, ge(check)
sum check
while r(N) < $total {
	bysort HS6 (DDT_NCH6): replace DDT_NCH6 = DDT_NCH6[_n+1] if missing(DDT_NCH6)
	cap drop check
	encode DDT_NCH6, ge(check)
	sum check
}
drop check


reshape long value_ , i( HS6 year DDT_NCH6 ) j(treatment) string

keep HS6  treatment year value_ DDT_NCH6 

local type "Nonelig"
foreach x of local type{
	preserve
	keep if DDT_NCH6=="`x'"
	
	ge d_treated = treatment =="Exp"

	ge first_tall = d_treated*2015
	recode first_tall (0=.)

	gen K = year-first_tall // "relative time", i.e. the number periods since treated (could be missing if never-treated)
	gen D = K>=0 & first_tall!=.
	tab K 

	sum first_tall
	gen lastcohort = first_tall==r(max) // dummy for the latest- or never-treated cohort
	forvalues l = 0/4 {
		gen L`l'event = K==`l'
	}
	forvalues l = 1/7 {
		gen F`l'event = K==-`l'
	}
	drop F1event // normalize K=-1 (and also K=-15) to zero

	tab year, ge(d_year)

	forvalues i = 1(1)12{
	ge id_treated_`i' = d_treated * d_year`i'
		}
	drop d_year7 id_treated_7		
	

	ge lvalue = ln(1 + value)
	
	table  year d_treated, stat(mean value) 
	table  year d_treated, stat(mean lvalue) 
	
	ge HS4 = substr(HS6, 1, 4)
	reghdfe value F*event L*event , a( year  HS6 ) cluster(HS6) 
		mat b=e(b) 
		local colnames : colnames b
		local colnames : subinstr local colnames "_cons" "F1event", all
		mat colnames b= `colnames'
		mat b[1,colnumb(b,"F1event")] = 0
		erepost b= b, rename
		mat v = e(V)
		mat v[12,12] = 0
		erepost V = v, rename
estimates store ev1
	
		event_plot ev1 , ///
			stub_lag(  L#event  ) stub_lead(  F#event  ) alpha(0.1) plottype(scatter) ciplottype(rcap) ///
			together perturb(-0(0.0)0.0) trimlead(6) noautolegend ///
			graph_opt( xtitle("", size(medlarge) ) name(top10, replace) legend(off) ///
			ytitle("Coefficient") xlabel( -6 "2009" -5 "2010" -4 "2011" -3 "2012"  ///
			-2 "2013" -1 "2014"  0 "2015" 1 "2016" 2 "2017" 3 "2018" 4 "2019", angle(vertical)) xline(-0.5, lcolor(gs8) lpattern(dash)) ///
			yline(0, lcolor(gs8)) graphregion(color(white)) bgcolor(white) ///
			ylabel(, angle(horizontal))) lag_opt1(msymbol(O) color(black)) ///
			lag_ci_opt1(color(black)) 	
		graph export "output/figures/miss_ev_Nonelig_top10.png", replace	
	restore
}


use "output/Data_for_misreporting_all_NC", clear

* top 10 non EU
keep if country=="USA" | country=="CHN" | country=="CAN" | country=="AGY" | country=="HKG" ///
	  | country=="KOR" | country=="LKA" | country=="TUR" | country=="ARE" | country=="ZAF" 	  

rename ExpvUSD value_Exp
rename ImpvUSD value_Imp

ge post = year>2015

** Analysis by treatment category for textile products
collapse  value* , by( HS6  year DDT_NCH6 ) 
fillin   HS6 year  

sum year
global total = r(N)
cap drop check
encode DDT_NCH6, ge(check)
sum check
while r(N) < $total {
	bysort HS6 (DDT_NCH6): replace DDT_NCH6 = DDT_NCH6[_n+1] if missing(DDT_NCH6)
	cap drop check
	encode DDT_NCH6, ge(check)
	sum check
}
drop check


reshape long value_ , i( HS6 year DDT_NCH6 ) j(treatment) string

keep HS6  treatment year value_ DDT_NCH6 

local type "Nonelig"
foreach x of local type{
	preserve
	keep if DDT_NCH6=="`x'"
	
	ge d_treated = treatment =="Exp"

	ge first_tall = d_treated*2015
	recode first_tall (0=.)

	gen K = year-first_tall // "relative time", i.e. the number periods since treated (could be missing if never-treated)
	gen D = K>=0 & first_tall!=.
	tab K 

	sum first_tall
	gen lastcohort = first_tall==r(max) // dummy for the latest- or never-treated cohort
	forvalues l = 0/4 {
		gen L`l'event = K==`l'
	}
	forvalues l = 1/7 {
		gen F`l'event = K==-`l'
	}
	drop F1event // normalize K=-1 (and also K=-15) to zero

	tab year, ge(d_year)

	forvalues i = 1(1)12{
	ge id_treated_`i' = d_treated * d_year`i'
		}
	drop d_year7 id_treated_7		
	

	ge lvalue = ln(1 + value)
	
	table  year d_treated, stat(mean value) 
	table  year d_treated, stat(mean lvalue) 
	
	ge HS4 = substr(HS6, 1, 4)
	reghdfe value F*event L*event , a( year  HS6 ) cluster(HS6 )
		mat b=e(b) 
		local colnames : colnames b
		local colnames : subinstr local colnames "_cons" "F1event", all
		mat colnames b= `colnames'
		mat b[1,colnumb(b,"F1event")] = 0
		erepost b= b, rename
		mat v = e(V)
		mat v[12,12] = 0
		erepost V = v, rename
estimates store ev1
	
		event_plot ev1 , ///
			stub_lag(  L#event  ) stub_lead(  F#event  ) alpha(0.1) plottype(scatter) ciplottype(rcap) ///
			together perturb(-0(0.0)0.0) trimlead(6) noautolegend ///
			graph_opt( xtitle("", size(medlarge) ) name(noEu, replace) legend(off) ///
			ytitle("Coefficient") xlabel( -6 "2009" -5 "2010" -4 "2011" -3 "2012"  ///
			-2 "2013" -1 "2014"  0 "2015" 1 "2016" 2 "2017" 3 "2018" 4 "2019", angle(vertical)) xline(-0.5, lcolor(gs8) lpattern(dash)) ///
			yline(0, lcolor(gs8)) graphregion(color(white)) bgcolor(white) ///
			ylabel(, angle(horizontal))) lag_opt1(msymbol(O) color(black)) ///
			lag_ci_opt1(color(black)) 	
		graph export "output/figures/miss_ev_Nonelig_top10noEU.png", replace	
	restore
}

