use  "output/Data_for_synt_DDTCh", clear
rename Exports Exports1

merge 1:1 reporteriso3 year DDTCh using "output/Data_for_synt_DDTCh"
order Exports Exports1
br if Exports != Exports1
ge diff = Exports1 - Exports
order diff
sort diff

drop if DDTCh=="Notextile"
drop countryid
replace Exports = Exports/1000000
drop if year ==2007

mat drop _all

drop if reporteriso3=="HKG"
cap drop count
bysort reporteriso3 : ge count = _N
tab count
keep if count==48 // balanced panel

bysort reporteriso3 DDTCh: egen tottextile = total(Exports) if DDTCh!="Notextile"
bysort DDTCh: egen tottot = total(Exports) if DDTCh!="Notextile"
ge sharetemp = tottextile/tottot
bysort reporteriso3: egen share = max(share)

egen countryid = group(reporteriso)

sum countryid if reporteris =="PAK"
global PAK = r(mean)


levelsof DDTCh, local(lDDTCh)

foreach i of local lDDTCh{
	preserve
	display "`i'"
	global type = "`i'"
	keep if DDTCh=="`i'"
	xtset countryid year
	replace share = -share
	bysort year (share): gen order = _n
	keep if order<=40
	bysort reporteriso3: ge numcountries = _N
	sum numcountries
	global max = r(max)
	sum countryid if year == 2010
	global Num = r(N)
	drop if numcountries<$max
	drop numcountries
	levelsof countryid, local(countrylist)
	sum countryid
	global min = r(min)
	
	foreach s of local  countrylist {
			#delimit; 
			synth   Exports  
					Exports(2009)  Exports(2011) Exports(2012)  Exports(2013) Exports(2014)  ,       
					trunit(`s') trperiod(2015) unitnames(reporteriso3) 
					mspeperiod(2009(1)2015) resultsperiod(2009(1)2019)
					keep(output/placebo`i'_`s')  replace;
					matrix country`i'_`s' = e(RMSPE);
					mat list e(V_matrix);
			#delimit cr 
		}

	display "  *******  Computing gap ******** "	
	foreach s of local countrylist {
		use output/placebo`i'_`s' ,clear
		keep _Y_treated _Y_synthetic _time
		drop if _time==.
		rename _time year
		rename _Y_treated  treat`s'
		rename _Y_synthetic counterfact`s'
		gen gap`s'=treat`s'-counterfact`s'
		sort year 
		tempfile gap`i'_`s'
		save `gap`i'_`s''
    }

	display "  *******  Merging   *******  "
	use `gap`i'_${min}'	
	foreach s of local countrylist {
        merge 1:1 year using `gap`i'_`s''
        drop _merge 
        sort year 
		duplicates drop
		save output/all_`i', replace 
    }

	display "  *******  Graph   *******  "	
	use output/all_`i', replace	
	
	foreach s of local countrylist {
		ge outlier`s' = gap`s' / gap${PAK} if year<2014
		sum outlier`s'
		if abs(r(mean)) > 5{
			drop gap`s'
			}
	}
	
	keep gap* year 

	twoway  (line gap* year, lpattern(solid solid) lcolor(gs13 gs13) )  ///
			(line gap${PAK} year, lpattern(solid solid) lcolor(red)) ///
			, scheme(s1mono) xlabel(2008(1)2019) name(placebo`i', replace) legend(off)
			graph export "output/figures/inf_`i'_NC.png",  replace

restore
}			
			
