

*Data from 2005-2010 and 2015-2017 are from the Central Bank of Pakistan and data from 2018-2021 are from Ministry of Commerce.

use "Input/Exporter_transaction_2008_2021.dta", replace
	drop if year<2003 // seems HS code was different
	collapse  (mean) export_value, by(NTN year)
	bysort NTN: egen minyear = min(year)
	ge entry = year == minyear
	ge incumbent = year>minyear
	bysort NTN (year): ge gap = year - year[_n-1] // Consecutive years
	bysort NTN: egen mingap = min(gap)
	drop if mingap>1 // drop exporters that never have consecutive yearw
	bysort NTN: drop if _N==1 // drop exporters that only appears ones 	
	keep NTN year entry minyear incumbent
	count
	save "output/entry_NC.dta", replace
	
	
use "input/Exporter_transaction_2008_2021.dta", replace
	drop if year<2003 // seems HS code was different
	collapse  (mean) export_value, by(NTN year)
	bysort NTN: egen maxyear = max(year)
	ge exit = year == maxyear
	sort NTN year
	bysort NTN (year): ge gap = year - year[_n-1] // Consecutive years
	bysort NTN: egen mingap = min(gap)
	drop if mingap>1 // drop exporters that never have consecutive yearw
	bysort NTN: drop if _N==1 // drop exporters that only appears ones 
	// Keep exporters that are observed for at least 2 consecutive years
	keep NTN year exit maxyear 
	count
	save "output/exit_NC.dta", replace	

**** Analysis
use "Input/Exporter_transaction_2008_2021.dta", replace

egen exporterid = group(NTN year)

order exporterid year  HS6 export_value DDT_NCH6
sort year exporterid HS6 

drop if year<2005 // seems HS code was different

tab HS6 if DDT_NCH6=="" & HS2n>=50 & HS2n<=63
ge flag = 1 if DDT_NCH6=="" & HS2n>=50 & HS2n<=63

tab year if flag==1
drop if flag==1 // these are dropped because the HS code is incorrect (329 observations is removing 2007) // More if 
drop flag

ge textile = HS2n>=50 & HS2n<=63 
bysort exporterid year: egen FF_textile = mean(textile)
drop if FF_textile==0 // drop if not export textile
keep if textile==1 // keep only textile exports


ge H6_highrate = DDT_NCH6=="Garments" | DDT_NCH6=="Madeups"
ge H6_lowrate = DDT_NCH6=="FabricYarn" | DDT_NCH6=="Nonelig" | DDT_NCH6=="Processed"

bysort exporterid year: egen mean_high = mean(H6_highrate)
bysort exporterid H6_highrate year: egen totexp_high = total(export_value)

bysort exporterid year: egen mean_low= mean(H6_lowrate)
bysort exporterid H6_lowrate year: egen totexp_low = total(export_value)

ge nohigh =  mean_low == 1

ge export_value_textile = export_value if textile==1
bysort exporterid year: egen totexp = total(export_value_textile)
ge specialised = mean_high==1
ge share_high = totexp_high/totexp if H6_highrate==1
replace share_high = 0 if mean_high==0


** Entry
preserve
merge m:1 NTN year using "output/entry_NC.dta"
drop if _m==2
	
	collapse (mean) specialised nohigh share_high entry incumbent , by(exporterid year)
	
	replace share_high 	= . if year==2015 | year == 2018  | year == 2005
	replace specialised = . if year==2015 | year == 2018  | year == 2005	
	replace nohigh 		= . if year==2015 | year == 2018  | year == 2005

	ge post = year>2015
	drop if year==2005 | year==2015 | year==2018

	reg specialised entry##post i.year, cluster(exporterid)
	estimates store reg1
	sum specialised
	
	reg nohigh entry##post i.year, cluster(exporterid)	
	estimates store reg2
	sum nohigh
	
	
	esttab reg1 reg2  , 	nocons cells(b(fmt(3) star) se(fmt(3) par)  )    /// 
	starlevels(* 0.1 ** 0.05 *** 0.01) stats(N df_a , fmt(0 0 ))	///
	nogaps noomit indicate( "Year FE = *year*" ) drop(0.* _cons) 
	
restore


** Exit
merge m:1 NTN year using "output/exit_NC.dta"
drop if _m==2
	
	collapse (mean) specialised nohigh share_high exit  , by(exporterid year)
	
	replace share_high 	= . if year==2010 | year == 2017  | year == 2021
	replace specialised = . if year==2010 | year == 2017  | year == 2021	
	replace nohigh 		= . if year==2010 | year == 2017  | year == 2021
	
	ge post = year>2015
	
	drop if year==2010 | year == 2017  | year == 2021
	tab year, ge(d_year)

	reg specialised exit##post i.year, cluster(exporterid)
	estimates store exreg1

	reg nohigh exit##post i.year, cluster(exporterid)	
	estimates store exreg2
		
	esttab  exreg1 exreg2  , 	nocons cells(b(fmt(3) star) se(fmt(3) par)  )    /// 
	starlevels(* 0.1 ** 0.05 *** 0.01) stats(N df_a , fmt(0 0 )) drop(0.* _cons) 	///
	nogaps noomit indicate( "Year FE = *year*" )
	
	esttab reg1 reg2 exreg1 exreg2  using "output/tables/Table2", csv replace 	///
	nocons cells(b(fmt(3) star) se(fmt(3) par)  )  drop(0.* _cons)   /// 
	starlevels(* 0.1 ** 0.05 *** 0.01) stats(N df_a , fmt(0 0 ))	nogaps noomit indicate( "Year FE = *year*" )
		
